<?php
/**
 * Plugin Name:       Kaira Customisations
 * Description:       A simple plugin to add your own custom php functions, jQuery or CSS to the Kaira Child themes.
 * Plugin URI:        https://kairawp.com/
 * Version:           1.0.0
 * Author:            Kaira
 * Author URI:        https://kairaweb.com/
 * Requires at least: 3.0.0
 * Tested up to:      4.4.2
 *
 * @package Kaira_Customisations
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Main Kaira_Customisations Class
 */
final class Kaira_Customisations {

	/**
	 * Set up the plugin
	 */
	public function __construct() {
		add_action( 'init', array( $this, 'kaira_customisations_setup' ), -1 );
		require_once( 'custom/functions.php' );
	}

	/**
	 * Setup all the things
	 */
	public function kaira_customisations_setup() {
		add_action( 'wp_enqueue_scripts',  array( $this, 'kaira_customisations_css' ), 999 );
		add_action( 'wp_enqueue_scripts',  array( $this, 'kaira_customisations_js' ) );
		add_filter( 'template_include',    array( $this, 'kaira_customisations_template' ), 11 );
		add_filter( 'wc_get_template',     array( $this, 'kaira_customisations_wc_get_template' ), 11, 5 );
		// Add settings link to plugins page
		add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), array( $this, 'kaira_add_settings_links' ) );
	}

	/**
	 * Enqueue the CSS
	 */
	public function kaira_customisations_css() {
		wp_enqueue_style( 'custom-css', plugins_url( '/custom/style.css', __FILE__ ) );
	}

	/**
	 * Enqueue the Javascript
	 */
	public function kaira_customisations_js() {
		wp_enqueue_script( 'custom-js', plugins_url( '/custom/custom.js', __FILE__ ), array( 'jquery' ) );
	}

	/**
	 * Look in this plugin for template files first.
	 * This works for the top level templates (IE single.php, page.php etc). However, it doesn't work for
	 * template parts yet (content.php, header.php etc).
	 *
	 * Relevant trac ticket; https://core.trac.wordpress.org/ticket/13239
	 *
	 * @param  string $template template string.
	 * @return string $template new template string.
	 */
	public function kaira_customisations_template( $template ) {
		if ( file_exists( untrailingslashit( plugin_dir_path( __FILE__ ) ) . '/custom/templates/' . basename( $template ) ) ) {
			$template = untrailingslashit( plugin_dir_path( __FILE__ ) ) . '/custom/templates/' . basename( $template );
		}

		return $template;
	}

	/**
	 * Look in this plugin for WooCommerce template overrides.
	 *
	 * For example, if you want to override woocommerce/templates/cart/cart.php, you
	 * can place the modified template in <plugindir>/custom/templates/woocommerce/cart/cart.php
	 *
	 * @param string $located is the currently located template, if any was found so far.
	 * @param string $template_name is the name of the template (ex: cart/cart.php).
	 * @return string $located is the newly located template if one was found, otherwise
	 *                         it is the previously found template.
	 */
	public function kaira_customisations_wc_get_template( $located, $template_name, $args, $template_path, $default_path ) {
		$plugin_template_path = untrailingslashit( plugin_dir_path( __FILE__ ) ) . '/custom/templates/woocommerce/' . $template_name;

		if ( file_exists( $plugin_template_path ) ) {
			$located = $plugin_template_path;
		}

		return $located;
	}

	/**
	 * Add edit links to plugin list table
	 * @param  array $links Existing links
	 * @return array 		Modified links
	 */
	public function kaira_add_settings_links ( $links ) {
		$settings_link = '<a href="plugin-editor.php?file=kaira-customisations%2Fcustom%2Ffunctions.php&plugin=kaira-customisations%2Fkaira-customisations.php">' . 'PHP' . '</a> |';
		$settings_link .= ' <a href="plugin-editor.php?file=kaira-customisations%2Fcustom%2Fcustom.js&plugin=kaira-customisations%2Fkaira-customisations.php">' . 'Javascript' . '</a> |';
		$settings_link .= ' <a href="plugin-editor.php?file=kaira-customisations%2Fcustom%2Fstyle.css&plugin=kaira-customisations%2Fkaira-customisations.php">' . 'CSS' . '</a>';
  		array_push( $links, $settings_link );
  		return $links;
	}
} // End Class

/**
 * The 'main' function
 *
 * @return void
 */
function kaira_customisations_main() {
	new Kaira_Customisations();
}

/**
 * Initialise the plugin
 */
add_action( 'plugins_loaded', 'kaira_customisations_main' );
